@@ -62,6 +62,7 @@ function usage($error = false) {
   -to "<date>"                           ignore lines logged after this date (uses strtotime)
   -database <database>                   consider only queries on this database
   -user <user>                           consider only queries executed by this user
+  -keepformatting                        keep the formatting of the query
   -title <title>                         define the title of the reports
   -syslogident <ident>                   PostgreSQL syslog identity. Default is postgres.
   -memorylimit <n>                       PHP memory limit in MB. Default is 128.
@@ -312,14 +313,21 @@ if(isset($options['user']) && !empty($options['user'])) {
 	define('CONFIG_USER', false);
 }
 
+if(isset($options['keepformatting'])) {
+	define('CONFIG_KEEP_FORMATTING', true);
+} else {
+	define('CONFIG_KEEP_FORMATTING', false);
+}
+
 if(isset($options['from']) && !empty($options['from'])) {
-	$fromTimestamp = strtotime($options['from']);
+	$fromTimestamp = strtotime($options['to']);
 	if($fromTimestamp <= 0) {
 		$fromTimestamp = false;
 	}
 } else {
 	$fromTimestamp = false;
 }
+define('CONFIG_FROM_TIMESTAMP', $fromTimestamp);
 
 if(isset($options['to']) && !empty($options['to'])) {
 	$toTimestamp = strtotime($options['to']);
@@ -329,19 +337,10 @@ if(isset($options['to']) && !empty($options['to'])) {
 } else {
 	$toTimestamp = false;
 }
+define('CONFIG_TO_TIMESTAMP', $toTimestamp);
 
-if($fromTimestamp || $toTimestamp) {
+if(CONFIG_FROM_TIMESTAMP || CONFIG_TO_TIMESTAMP) {
 	define('CONFIG_TIMESTAMP_FILTER', true);
-	if($fromTimestamp) {
-		define('CONFIG_FROM_TIMESTAMP', $fromTimestamp);
-	} else {
-		define('CONFIG_FROM_TIMESTAMP', MIN_TIMESTAMP);
-	}
-	if($toTimestamp) {
-		define('CONFIG_TO_TIMESTAMP', $toTimestamp);
-	} else {
-		define('CONFIG_TO_TIMESTAMP', MAX_TIMESTAMP);
-	}
 } else {
 	define('CONFIG_TIMESTAMP_FILTER', false);
 }
@@ -368,6 +367,4 @@ $logReader->output();
 
 fclose($stderr);
 
-exit(0);
-
 ?>
\ No newline at end of file
